<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Seafile Drive Client %2&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Seafile Drive Client %2&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation>&lt;h5&gt; REV %1 &lt;/h5&gt;</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>Fehler beim Aufruf der Kontodatenbank</translation>
    </message>
</context>
<context>
    <name>AutoLogonDialog</name>
    <message>
        <source>auto login</source>
        <translation>Automatisch anmelden</translation>
    </message>
    <message>
        <source>auto logining, please wait a moment</source>
        <translation>Automatisches Anmelden, bitte warten Sie</translation>
    </message>
    <message>
        <source>Please input server address</source>
        <translation>Bitte geben Sie die Serveradresse ein</translation>
    </message>
    <message>
        <source>address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Geben Sie die Serveradresse ein</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 ist keine gültige Serveradresse</translation>
    </message>
    <message>
        <source>login failed</source>
        <translation>Anmeldung fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>%1 failed to initialize</source>
        <translation>%1 konnte nicht initialisiert werden.</translation>
    </message>
    <message>
        <source>%1 exited unexpectedly</source>
        <translation>%1 wurde unvorhergesehen ausgeworfen.</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create seadrive mount folder</source>
        <translation>Fehler bei der Initialisierung: konnte keinen Seadrive Mount-Ordner erstellen</translation>
    </message>
</context>
<context>
    <name>EncryptedReposDialog</name>
    <message>
        <source>Encrypted Libraries</source>
        <translation>Verschlüsselte Bibliotheken</translation>
    </message>
    <message>
        <source>No Encrypted Library.</source>
        <translation>Es sind keine verschlüsselten Bibliotheken vorhanden.</translation>
    </message>
</context>
<context>
    <name>EncryptedReposTableModel</name>
    <message>
        <source>Failed to set encrypted library password</source>
        <translation>Das Passwort für die verschlüsselte Bibliothek konnte nicht gesetzt werden.</translation>
    </message>
    <message>
        <source>Password error</source>
        <translation>Das Passwort ist falsch.</translation>
    </message>
    <message>
        <source>Failed to clear encrypted library password</source>
        <translation>Das Passwort für die verschlüsselte Bibliothek konnte nicht zurückgesetzt werden.</translation>
    </message>
    <message>
        <source>Right click this item to sync or unsync the encrypted library</source>
        <translation>Rechtsklick zum Starten oder Aufheben der Synchronisierung der verschlüsselten Bibliothek</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliothek</translation>
    </message>
    <message>
        <source>Sync status</source>
        <translation>Status der Synchronisation</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
</context>
<context>
    <name>EncryptedReposTableView</name>
    <message>
        <source>Unsync</source>
        <translation>Synchronisation aufheben</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Synchronisieren</translation>
    </message>
    <message>
        <source>After unsyncing, the local encryption key of this library will be cleared and this library cannot be accessed in virtual drive. Are you sure to unsync?</source>
        <translation>Mit dem Aufheben der Synchronisation wird der lokale Schlüssel für diese Bibliothek gelöscht. Danach ist diese verschlüsselte Bibliothek lokal nicht mehr verfügbar. Möchten Sie die Synchronisation wirklich aufheben?</translation>
    </message>
    <message>
        <source>Enter library password to sync</source>
        <translation>Passwort der verschlüsselten Bibliothek</translation>
    </message>
</context>
<context>
    <name>ExtCommandsHandler</name>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
        <translation>Möchten Sie wirklich den Account aus &quot;%1&quot; entfernen? Heruntergeladene und hochgeladene Dateien werden nicht gelöscht.</translation>
    </message>
    <message>
        <source>Failed to connect to background process, please try again later</source>
        <translation>Der Hintergrundprozess konnte nicht aufgerufen werden. Bitte versuchen Sie es später noch einmal</translation>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
        <translation>Möchten Sie wirklich den Account aus &quot;%1&quot; neu synchronisieren? Heruntergeladene und hochgeladene Dateien werden nicht gelöscht.</translation>
    </message>
</context>
<context>
    <name>FileProviderManager</name>
    <message>
        <source>%1 will ask permissions to enable Finder plugin.</source>
        <translation>%1 wird um die Bestätigung der Aktivierung des Finder Plugins bitten.</translation>
    </message>
</context>
<context>
    <name>FilterMenu</name>
    <message>
        <source>FilterMenu</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Text file    </source>
        <translation>Textdatei</translation>
    </message>
    <message>
        <source>Document    </source>
        <translation>Dokument</translation>
    </message>
    <message>
        <source>Image    </source>
        <translation>Bild</translation>
    </message>
    <message>
        <source>Video    </source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Audio    </source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Markdown</source>
        <translation>Markdown</translation>
    </message>
</context>
<context>
    <name>InitSyncDialog</name>
    <message>
        <source>Download files list</source>
        <translation>Dateiliste herunterladen</translation>
    </message>
    <message>
        <source>%1 is fetching the files list, please wait</source>
        <translation>%1 lädt die Dateiliste, bitte warten ...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>Logo</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Im Hintergrund ausführen</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <source>%1 has downloaded your files list.</source>
        <translation>%1 hat Ihre Dateiliste heruntergeladen.</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation>mehr laden</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Konto hinzufügen</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation>Single Sign-On</translation>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Erneut anmelden</translation>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Anmeldung wird durchgeführt …</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Netzwerkfehler:
 %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Warnung:&lt;/b&gt; Das SSL-Zertifikat dieses Servers ist nicht vertrauenswürdig. Wollen Sie trotzdem fortfahren?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Geben Sie die Serveradresse ein</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 ist keine gültige Serveradresse.</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Geben Sie den Benutzernamen ein</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>Geben Sie den Rechnernamen ein</translation>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation>2-Faktor-Authentifizierung</translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation>%1-Serveradresse</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Geben Sie das Passwort ein</translation>
    </message>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation>Geben Sie den Token der 2-Faktor-Authentifizierung ein</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>E-Mail-Adresse oder Passwort sind ungültig.</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>Zu viele Anmeldeversuche, warten Sie eine Minute.</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Interner Serverfehler</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Fehler beim Anmelden: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Fehler beim Anmelden</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>Logo</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>oder http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Automatic Login</source>
        <translation>Automatisch anmelden</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>Statustext</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Rechnername:</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation>E-Mail / Benutzername:</translation>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>z.B. Freyas Laptop</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Failed to get server info. Please check the server address.</source>
        <translation>Die Server-Information konnte nicht abgerufen werden. Bitte überprüfen Sie die URL des Servers.</translation>
    </message>
    <message>
        <source>Failed to get client sso link.</source>
        <translation>Der Link des Single Sign-On konnte nicht abgerufen werden.</translation>
    </message>
    <message>
        <source>SSO login failed.</source>
        <translation>Single Sign-on ist fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Failed to get client sso status.</source>
        <translation>Der Status des Single Sign-On konnte nicht abgerufen werden.</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://example.your-server.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Zum Beispiel: https://example.your-server.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation>Erweiterte Einstellungen</translation>
    </message>
    <message>
        <source>Sync Root Folder Name:</source>
        <translation>Basisordner für die Synchronisierung:</translation>
    </message>
    <message>
        <source>Sync root folder name cannot be empty</source>
        <translation>Basisordner für die Synchronisierung ist erforderlich</translation>
    </message>
    <message>
        <source>Sync root folder name cannot contain the following characters: &lt; &gt; : &quot; / \ | ? *</source>
        <translation>Die Bezeichnung des Basisordners für die Synchronisierung darf nicht enthalten: &lt; &gt; : &quot; / \ | ? *</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Files in this account will be synced under the path like &apos;C:\Users\Jim\seadrive_root\&amp;lt;sync root folder name&amp;gt;&apos;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Synchronisierungen dieses Accounts werden in einem Dateipfad abgelegt, der etwa so lautet: &apos;C:\Users\XY\seadrive_root\&amp;lt;BASISORDNER&amp;gt;&apos;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MessagePoller</name>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation>&quot;%1&quot; wurde synchronisiert.</translation>
    </message>
    <message>
        <source>Error when syncing &quot;%1&quot;</source>
        <translation>Fehler bei der Synchronisation &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Error when syncing</source>
        <translation>Fehler bei der Synchronisation</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is being uploaded</source>
        <translation>„%1“ wird hochgeladen</translation>
    </message>
    <message>
        <source>Starting to move &quot;%1&quot;</source>
        <translation>Beginne &quot;%1&quot; zu verschieben</translation>
    </message>
    <message>
        <source>Starting to move &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Beginne &quot;%1&quot; zu &quot;%2&quot; zu verschieben</translation>
    </message>
    <message>
        <source>Successfully moved &quot;%1&quot;</source>
        <translation>&quot;%1&quot; wurde erfolgreich verschoben.</translation>
    </message>
    <message>
        <source>Successfully moved &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>&quot;%1&quot; wurde erfolgreich zu &quot;%2&quot; verschoben.</translation>
    </message>
    <message>
        <source>Failed to move &quot;%1&quot;</source>
        <translation>Das Verschieben von &quot;%1&quot; ist fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Failed to move &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Das Verschieben von &quot;%1&quot; zu &quot;%2&quot; ist fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Download file</source>
        <translation>Datei herunterladen</translation>
    </message>
    <message>
        <source>Start to download file &quot;%1&quot; </source>
        <translation>Beginne &quot;%1&quot; herunterzuladen</translation>
    </message>
    <message>
        <source>file &quot;%1&quot; has been downloaded </source>
        <translation>&quot;%1&quot; wurde heruntergeladen.</translation>
    </message>
    <message>
        <source>Failed to create file &quot;%1&quot;</source>
        <translation>Datei „%1“ konnte nicht erstellt werden.</translation>
    </message>
    <message>
        <source>Failed to delete folder</source>
        <translation>Der Ordner konnte nicht gelöscht werden.</translation>
    </message>
    <message>
        <source>You can&apos;t delete the library &quot;%1&quot; directly</source>
        <translation>Sie können die Bibliothek „%1“ nicht direkt löschen.</translation>
    </message>
    <message>
        <source>Libraries are ready</source>
        <translation>Bibliotheken stehen bereit</translation>
    </message>
    <message>
        <source>All libraries are loaded and ready to use.</source>
        <translation>Alle Bibliotheken sind geladen und können verwendet werden.</translation>
    </message>
    <message>
        <source>Deleted &quot;%1&quot; and %2 more files.</source>
        <translation>Die Datei &quot;%1&quot; und %2 weitere Dateien wurden gelöscht.</translation>
    </message>
    <message>
        <source>You can&apos;t create files in the mount folder directly</source>
        <translation>Sie können keine Dateien direkt im Mount-Ordner erstellen.</translation>
    </message>
    <message>
        <source>Do you want to delete files in library &quot;%1&quot; ?</source>
        <translation>Möchten Sie die Dateien in der Bibliothek &quot;%1&quot; löschen? </translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Die Bibliothek &quot;%1&quot; wurde gelöscht.</translation>
    </message>
    <message>
        <source>Confirm to delete library &quot;%1&quot; ?</source>
        <translation>Möchten Sie die Bibliothek &quot;%1&quot; löschen?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>File %1 is locked by other programs</source>
        <translation>Die Datei &quot;%1&quot; ist durch ein anderes Programm gesperrt.</translation>
    </message>
    <message>
        <source>Some file is locked by other programs</source>
        <translation>Eine Datei ist durch ein anderes Programm gesperrt.</translation>
    </message>
    <message>
        <source>Folder %1 is locked by other programs</source>
        <translation>Der Ordner &quot;%1&quot; ist durch ein anderes Programm gesperrt.</translation>
    </message>
    <message>
        <source>Some folder is locked by other programs</source>
        <translation>Ein Ordner ist von einem anderen Programm gesperrt.</translation>
    </message>
    <message>
        <source>File %1 is locked by another user</source>
        <translation>Die Datei &quot;%1&quot; ist durch einen anderen Benutzer gesperrt.</translation>
    </message>
    <message>
        <source>Some file is locked by another user</source>
        <translation>Eine Datei ist durch einen anderen Benutzer gesperrt</translation>
    </message>
    <message>
        <source>Invalid path %1</source>
        <translation>Fehlerhafter Pfad %1</translation>
    </message>
    <message>
        <source>Trying to access an invalid path</source>
        <translation>Versuchter Zugriff auf ungültigen Pfad</translation>
    </message>
    <message>
        <source>Error when indexing file %1</source>
        <translation>Fehler bei der Indizierung der Datei %1</translation>
    </message>
    <message>
        <source>Error when indexing files</source>
        <translation>Fehler bei der Indizierung von Dateien</translation>
    </message>
    <message>
        <source>You don&apos;t have enough permission for this library</source>
        <translation>Sie haben keine ausreichenden Rechte, um auf diese Bibliothek zuzugreifen.</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation>Netzwerkfehler</translation>
    </message>
    <message>
        <source>Failed to resolve network proxy</source>
        <translation>Adresse des Netzwerk-Proxy nicht gefunden</translation>
    </message>
    <message>
        <source>Failed to resolve remote server</source>
        <translation>Die Adresse des Servers wurde nicht gefunden.</translation>
    </message>
    <message>
        <source>Failed to connect to server</source>
        <translation>Die Verbindung mit dem Server ist fehlgeschlagen.</translation>
    </message>
    <message>
        <source>SSL error</source>
        <translation>SSL-Fehler</translation>
    </message>
    <message>
        <source>Error in network transmission</source>
        <translation>Fehler bei der Übertragung im Netzwerk</translation>
    </message>
    <message>
        <source>Timeout in network transmission</source>
        <translation>Zeitüberschreitung bei der Übertragung im Netzwerk</translation>
    </message>
    <message>
        <source>Failed to handle http redirection</source>
        <translation>Fehler bei der HTTP-Umleitung</translation>
    </message>
    <message>
        <source>Server internal error</source>
        <translation>Interner Serverfehler</translation>
    </message>
    <message>
        <source>Local data is corrupt</source>
        <translation>Lokale Daten sind defekt.</translation>
    </message>
    <message>
        <source>Failed to write local data</source>
        <translation>Lokale Daten konnten nicht geschrieben werden.</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>Das Speicherkontingent ist aufgebraucht.</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>SSL-Fehler</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Netzwerkfehler: %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Serverfehler</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>Die Bibliothek &quot;%1&quot; wurde erstellt.</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Die Bibliothek &quot;%1&quot; wurde gelöscht.</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>Hinzugefügt</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>Gelöscht</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>Entfernt</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>Geändert</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>Umbenannt</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation>Neu oder geändert</translation>
    </message>
    <message>
        <source>Moved</source>
        <translation>Verschoben</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>Ordner erstellt</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>Ordner gelöscht</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>Ordner umbenannt</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>Ordner verschoben</translation>
    </message>
    <message>
        <source>files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>und noch %1</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>Bibliothek zurückgesetzt zum Status vom</translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>Die Datei &quot;%1&quot; wurde auf den Status vom &quot;%2&quot; zurückgesetzt.</translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>Gelöschter Ordner wiederhergestellt</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>Name oder Beschreibung der Bibliothek geändert</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation>Automatische Zusammenführung durch %1 System</translation>
    </message>
    <message>
        <source>Just now</source>
        <translation>gerade eben</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>vor 1 Tag</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>vor %1 Tagen</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>vor 1 Stunde</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>vor %1 Stunden</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>vor 1 Minute</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>vor %1 Minuten</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation>Schreibgeschützter Ordner</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <source>PDF Document</source>
        <translation>PDF-Dokument</translation>
    </message>
    <message>
        <source>Image File</source>
        <translation>Bild</translation>
    </message>
    <message>
        <source>Text Document</source>
        <translation>Textdokument</translation>
    </message>
    <message>
        <source>Audio File</source>
        <translation>Audiodatei</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>Videodatei</translation>
    </message>
    <message>
        <source>Word Document</source>
        <translation>Word-Dokument</translation>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation>PowerPoint-Dokument</translation>
    </message>
    <message>
        <source>Excel Document</source>
        <translation>Excel-Dokument</translation>
    </message>
    <message>
        <source>%1 Client is already running</source>
        <translation>%1 Client ist bereits gestartet</translation>
    </message>
    <message>
        <source>Choose the disk letter for %1</source>
        <translation>Wählen Sie einen Buchstaben für %1</translation>
    </message>
    <message>
        <source>Update to file %1 denied by folder permission setting</source>
        <translation>Aktualisierung von %1 nicht möglich wegen fehlender Rechte im Ordner</translation>
    </message>
    <message>
        <source>Path %1 ends with space or period character</source>
        <translation>Der Pfad %1 endet unzulässig mit einem Leerzeichen oder einem Punkt</translation>
    </message>
    <message>
        <source>Path %1 contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation>Der Pfad %1 enthält unzulässige Zeichen wie &apos;|&apos; oder &apos;:&apos;</translation>
    </message>
    <message>
        <source>Created or updated a file %1 in a non-writable library or folder</source>
        <translation>Datei %1 wurde in einer Bibliothek oder einem Ordner angelegt bzw. aktualisiert</translation>
    </message>
    <message>
        <source>Concurrent updates to file %1. File is saved as conflict file</source>
        <translation>Dateikonflikt bei der Aktualisierung von %1. Die Datei ist als Konfliktversion gesichert</translation>
    </message>
    <message>
        <source>%1 is not added to a library and will not be uploaded</source>
        <translation>%1 wurde keiner Bibliothek hinzugefügt und wird daher nicht hochgeladen.</translation>
    </message>
    <message>
        <source>You can only move files/folders within a library or from one library to another library</source>
        <translation>Sie können Dateien oder Ordner nur innerhalb einer Bibliothek bzw. von einer Bibliothek in eine andere verschieben.</translation>
    </message>
    <message>
        <source>Syncing is denied by cloud-only permission settings</source>
        <translation>Synchronisieren ist nicht möglich, solange die Zugriffsrechte auf nur-online beschränkt sind</translation>
    </message>
    <message>
        <source>Do not have write permission to the library</source>
        <translation>Keine Schreibrechte für die Bibliothek</translation>
    </message>
    <message>
        <source>Waiting for confirmation to delete files</source>
        <translation>Die Löschbestätigung wir abgewartet.</translation>
    </message>
    <message>
        <source>The path %1 contains symbols that are not supported by the Windows system.</source>
        <translation>Der Dateipfad %1 enthält Zeichen, die von Windows nicht unterstützt werden.</translation>
    </message>
    <message>
        <source>Failed to upload file blocks. Please check network or firewall.</source>
        <translation>Einzelne Dateipakete konnten nicht hochgeladen werden. Bitte überprüfen Sie Ihr Netzwerk oder die Firewall.</translation>
    </message>
    <message>
        <source>Failed to download file. Please check disk space or folder permissions</source>
        <translation>Die Datei konnte nicht heruntergeladen werden. Bitte kontrollieren Sie den Speicherplatz oder die Berechtigungen im Ordner</translation>
    </message>
    <message>
        <source>Library cannot be synced since it has too many files.</source>
        <translation>Die Bibliothek kann nicht synchronisiert werden, weil sie zu viele Dateien enthält.</translation>
    </message>
    <message>
        <source>Files cannot be uploaded to this library due to file number limit settings.</source>
        <translation>Die Dateien können nicht hochgeladen werden, da sie die erlaubte Gesamtzahl an Dateien in dieser Bibliothek überschreiten.</translation>
    </message>
    <message>
        <source>Path has character case conflict with existing file or folder. Will not be downloaded</source>
        <translation>Der Dateipfad hat einen Konflikt mit der Großkleinschreibung einer bestehenden Datei oder eines Ordners. Herunterladen wird nicht möglich sein</translation>
    </message>
    <message>
        <source>Failed to change library name since some files are opened in it</source>
        <translation>Der Name der Bibliothek konnte nicht geändert werden, da Dateien in ihr geöffnet sind</translation>
    </message>
</context>
<context>
    <name>RemoteWipeService</name>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>Die Sitzung ist abgelaufen. Melden Sie sich neu an.</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login. You can find files that are not uploaded yet at ~/Library/CloudStorage</source>
        <translation>Ihre letztes  Login ist abgelaufen, bitte melden Sie sich neu an. Dateien, die noch nicht hochgeladen sind, finden Sie im Ordner ~/Library/CloudStorage</translation>
    </message>
</context>
<context>
    <name>SeaDriveRootDialog</name>
    <message>
        <source>Choose SeaDrive Cache Folder</source>
        <translation>Wählen Sie einen Ordner für den SeaDrive-Zwischenspeicher</translation>
    </message>
    <message>
        <source>Your files will appear in a local cache folder. Please choose the folder:</source>
        <translation>Ihre Dateien werden in einem lokalen Zwischenspeicher angezeigt. Bitte wählen Sie einen Ordner dafür:</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>ändern …</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Choose %1 Cache Folder </source>
        <translation>Wählen Sie einen Ordner für den %1-Zwischenspeicher</translation>
    </message>
    <message>
        <source>Choose %1 Cache Folder</source>
        <translation>Wählen Sie einen Ordner für den %1-Zwischenspeicher</translation>
    </message>
    <message>
        <source>Please choose %1 cache folder</source>
        <translation>Bitte wählen Sie einen Ordner für den %1-Zwischenspeicher</translation>
    </message>
    <message>
        <source>Create %1 folder failed!</source>
        <translation>Der Ordner für %1 konnte nicht angelegt werden!</translation>
    </message>
</context>
<context>
    <name>SeadriveGui</name>
    <message>
        <source>Failed to initialize log: %1</source>
        <translation>Initialisieren des Logs &quot;%1&quot; fehlgeschlagen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>failed to save client id</source>
        <translation>Speichern der Client-ID fehlgeschlagen</translation>
    </message>
    <message>
        <source>failed to access %1</source>
        <translation>Zugriff auf %1 fehlgeschlagen</translation>
    </message>
    <message>
        <source>incorrect client id</source>
        <translation>falsche Client-ID</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>Lesen von %1 ist fehlgeschlagen</translation>
    </message>
    <message>
        <source>Auto logon failed, fall back to manual login</source>
        <translation>Manuelle Anmeldung erforderlich, automatisch nicht möglich</translation>
    </message>
    <message>
        <source>Faild to choose a cache directory</source>
        <translation>Fehler bei der Auswahl eines Ordners für den Zwischenspeicher</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 folder</source>
        <translation>Fehler bei der Initialisierung: Es konnte kein %1 Ordner erstellt werden</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 logs folder</source>
        <translation>Fehler bei der Initialisierung: Es konnte kein %1 Ordner für Protokolle erstellt werden</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 data folder</source>
        <translation>Fehler bei der Initialisierung: Es konnte kein %1 Ordner für Dateien erstellt werden</translation>
    </message>
    <message>
        <source>Failed to create seadrive cache directory</source>
        <translation>Die Erstellung des Caching-Orders ist fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Faild to migrate old data</source>
        <translation>Die alten Daten konnten nicht migriert werden</translation>
    </message>
    <message>
        <source>SeaDrive %1 with multiple accounts cannot work with macOS version lower than 14.4. Please upgrade your macOS or downgrade SeaDrive to 3.0.9</source>
        <translation>SeaDrive %1 mit mehreren Accounts benötigt mindestens macOS 14.4. Bitte aktualisieren Sie Ihr Betriebssystem oder wechseln Sie zur älteren Version 3.0.9 von SeaDrive.</translation>
    </message>
    <message>
        <source>To start %1 extension for account %2, you need to click the %3 entry in Finder</source>
        <translation>Um die Erweiterung %1 für Account %2 zu starten, klicken Sie bitte auf den Eintrag %3 im Finder</translation>
    </message>
</context>
<context>
    <name>SeafileExtensionHandler</name>
    <message>
        <source>Failed to get upload link information for file &quot;%1&quot;</source>
        <translation>Für die Datei &quot;%1&quot; konnten die Informationen zum Upload-Link nicht abgerufen werden.</translation>
    </message>
    <message>
        <source>No permissions to create a shared link</source>
        <translation>Sie haben nicht die Berechtigung für die Erstellung eines Freigabelinks.</translation>
    </message>
    <message>
        <source>failed get internal link %1</source>
        <translation>Der Abruf des internen Links %1 ist fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Failed to lock file</source>
        <translation>Die Datei konnte nicht gesperrt werden.</translation>
    </message>
    <message>
        <source>Failed to unlock file</source>
        <translation>Die Datei konnte nicht entsperrt werden.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; is locked by %2</source>
        <translation>Datei &quot;%1&quot; ist durch %2 gesperrt.</translation>
    </message>
    <message>
        <source>Failed to get lock information for file &quot;%1&quot;</source>
        <translation>Der Abruf der Sperrinformationen für Datei &quot;%1&quot; ist fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Failed to get share link %1
</source>
        <translation>Der Abruf des Freigabelinks %1 ist fehlgeschlagen.
</translation>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation>%1 interner Link</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>In die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>%1 Internal Link:</source>
        <translation>%1 interner Link:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>internal error: failed to connect to %1 daemon</source>
        <translation>Interner Fehler: Keine Verbindung zum %1 Daemon</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation>Fehler bei der Dateisynchronisation anzeigen</translation>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>&amp;Protokollordner</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Den „Über“-Dialog der Anwendung anzeigen</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;On­line­hil­fe</translation>
    </message>
    <message>
        <source>Accounts</source>
        <translation>Konten</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>Nicht angemeldet</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Ein Konto hinzufügen</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Seafile Drive Client %2&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Seafile Drive Client %2&lt;/h2&gt;</translation>
    </message>
    <message>
        <source>Up %1, Down %2</source>
        <translation>Hochladen %1, Herunterladen %2</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <source>Transfer progress</source>
        <translation>Verlauf des Datentransfers</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation>öffne %1-Protokollordner</translation>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation>öffne %1-Onlinehilfe</translation>
    </message>
    <message>
        <source>Show encrypted libraries</source>
        <translation>Verschlüsselte Bibliotheken anzeigen</translation>
    </message>
    <message>
        <source>Starting ...</source>
        <translation>Startet ...</translation>
    </message>
    <message>
        <source>Resync</source>
        <translation>Neu synchronisieren</translation>
    </message>
    <message>
        <source>There are changes being uploaded under the account, please try again later</source>
        <translation>Gerade werden im Konto Änderungen hochgeladen. Bitte versuchen sie es später noch einmal.</translation>
    </message>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? After removing account, you can still find downloaded files at ~/Library/CloudStorage.</source>
        <translation>Möchten Sie wirklich den Account aus &quot;%1&quot; entfernen? Wenn Sie den Account austragen, können Sie heruntergeladene Dateien weiterhin finden unter  ~/Library/CloudStorage.</translation>
    </message>
    <message>
        <source>Failed to connect to background process, please try again later</source>
        <translation>Der Hintergrundprozess konnte nicht aufgerufen werden. Bitte versuchen Sie es später noch einmal</translation>
    </message>
    <message>
        <source>SeaDrive %1 with multiple accounts cannot work with macOS version lower than 14.4. Please upgrade your macOS or downgrade SeaDrive to 3.0.9</source>
        <translation>SeaDrive %1 mit mehreren Accounts benötigt mindestens macOS 14.4. Bitte aktualisieren Sie Ihr Betriebssystem oder wechseln Sie zur älteren Version 3.0.9 von SeaDrive.</translation>
    </message>
    <message>
        <source>Search files</source>
        <translation>Dateien durchsuchen</translation>
    </message>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
        <translation>Möchten Sie wirklich den Account aus &quot;%1&quot; entfernen? Heruntergeladene und hochgeladene Dateien werden nicht gelöscht.</translation>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
        <translation>Möchten Sie wirklich den Account aus &quot;%1&quot; neu synchronisieren? Heruntergeladene und hochgeladene Dateien werden nicht gelöscht.</translation>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? After resyncing account, you can still find downloaded files at ~/Library/CloudStorage.</source>
        <translation>Möchten Sie wirklich den Account aus &quot;%1&quot; neu synchronisieren? Wenn Sie den Account neu synchronisieren, können Sie heruntergeladene Dateien weiterhin finden unter  ~/Library/CloudStorage.</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search files</source>
        <translation>Dateien durchsuchen</translation>
    </message>
    <message>
        <source>All file types</source>
        <translation>Alle Dateitypen</translation>
    </message>
    <message>
        <source>Custom file type</source>
        <translation>Eigener Dateityp</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation>&lt;br/&gt;konnte nicht gefunden werden. Bitte %1</translation>
    </message>
    <message>
        <source>No result found</source>
        <translation>Keine Ergebnisse gefunden</translation>
    </message>
</context>
<context>
    <name>SearchItemsTableModel</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Kind</source>
        <translation>Art</translation>
    </message>
</context>
<context>
    <name>SearchItemsTableView</name>
    <message>
        <source>&amp;Open the file</source>
        <translation>Datei &amp;öffnen</translation>
    </message>
    <message>
        <source>&amp;Show in folder</source>
        <translation>Im Ordner &amp;anzeigen</translation>
    </message>
    <message>
        <source>File not found, maybe not synchorized yet</source>
        <translation>Datei nicht gefunden (vielleicht noch nicht synchronisiert)</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation>%1 nach der Anmeldung automatisch starten</translation>
    </message>
    <message>
        <source>Cache directory:</source>
        <translation>Ordner für Zwischenspeicher:</translation>
    </message>
    <message>
        <source>Enable search</source>
        <translation>Suche aktivieren</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Kein Proxy</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP-Proxy</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>Socks5-Proxy</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy-Einstellungen des Systems</translation>
    </message>
    <message>
        <source>enabled search</source>
        <translation>Suche aktiviert</translation>
    </message>
    <message>
        <source>disabled search</source>
        <translation>Suche deaktiviert</translation>
    </message>
    <message>
        <source>You have %1. Restart to apply it?</source>
        <translation>%1 eingestellt. Jetzt Neustart zum Ausführen?</translation>
    </message>
    <message>
        <source>Please choose the cache folder</source>
        <translation>Wählen Sie einen Ordner für den Zwischenspeicher</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation>Adresse des Proxy-Servers erforderlich</translation>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation>Port des Proxy-Servers ist fehlerhaft</translation>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation>Nutzername für den Proxy-Server erforderlich</translation>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation>Passwort für den Proxy-Server erforderlich</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>Benachrichtigen, wenn Bibliotheken synchronisiert sind</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>Temporäre Dateien von MS Office und LibreOffice synchronisieren</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>Maximale Download-Geschwindigkeit (kB/s):</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Maximale Upload-Geschwindigkeit (kB/s):</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation>Die Explorer-Symbole anzeigen</translation>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>Server-Zertifikat bei https-Synchronisierung nicht überprüfen</translation>
    </message>
    <message>
        <source>Cache clean interval (in minutes):</source>
        <translation>Intervall zum Bereinigen des Cache (in Minuten): </translation>
    </message>
    <message>
        <source>Cache size limit (in GB):</source>
        <translation>Maximale Cache Größe (in GB):</translation>
    </message>
    <message>
        <source>select...</source>
        <translation>auswählen …</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Erweitert</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>Sprache (Neustart erforderlich):</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>Proxy-Typ:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>Für den Proxy-Server ist ein Passwort erforderlich</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Enable search in finder</source>
        <translation>Lokale Suche aktivieren</translation>
    </message>
    <message>
        <source>You have changed language, Restart to apply it?</source>
        <translation>Sie haben die Sprache geändert. Jetzt Neustart zum Ausführen?</translation>
    </message>
    <message>
        <source>You have changed cache directory. Restart to apply it?</source>
        <translation>Sie haben den Ordner für den Zwischenspeicher geändert. Möchten Sie das jetzt aktivieren mit einem Neustart?</translation>
    </message>
    <message>
        <source>You have changed %1 cache folder. Restart to apply it?</source>
        <translation>Sie haben den Ordner für den %1 Zwischenspeicher geändert. Möchten Sie das jetzt aktivieren mit einem Neustart?</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Hide Windows incompatibility paths Message</source>
        <translation>Hinweis auf nicht kompatible Windows-Pfade ausblenden</translation>
    </message>
    <message>
        <source>Confirm before deleting files more than</source>
        <translation>Löschbestätigung anfordern bei mehr Dateien als</translation>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>Freigabe-Link</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>Freigabe-Link:</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation>Direkt-Download</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Passwort anzeigen</translation>
    </message>
    <message>
        <source>Expire days</source>
        <translation>Tage bis Ablauf</translation>
    </message>
    <message>
        <source>Generate link</source>
        <translation>Link erstellen</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Failed to generate share link: %1</source>
        <translation>Der Freigabelink %1 konnte nicht erstellt werden</translation>
    </message>
</context>
<context>
    <name>ShibLoginDialog</name>
    <message>
        <source>Single Sign On</source>
        <translation>Single Sign-On</translation>
    </message>
</context>
<context>
    <name>SyncCommand</name>
    <message>
        <source>No permissions to create a shared link</source>
        <translation>Sie haben nicht die Berechtigung für die Erstellung eines Freigabelinks</translation>
    </message>
    <message>
        <source>failed to get share link %1</source>
        <translation>Der Abruf des Freigabelinks %1 ist fehlgeschlagen</translation>
    </message>
    <message>
        <source>failed get internal link %1</source>
        <translation>Der Abruf des internen Links %1 ist fehlgeschlagen</translation>
    </message>
    <message>
        <source>Failed to get upload link for file &quot;%1&quot;</source>
        <translation>Der Abruf des Upload-Links für die Datei &quot;%1&quot; ist fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation>Fehler bei der Dateisynchronisation</translation>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation>Keine Fehler bei der Synchronisation</translation>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation>Bibliothek mit Doppelklick öffnen</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliothek</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Pfad</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
</context>
<context>
    <name>TransferItemsTableModel</name>
    <message>
        <source>finished</source>
        <translation>abgeschlossen</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
</context>
<context>
    <name>TransferProgressDialog</name>
    <message>
        <source>Transfer Progress</source>
        <translation>Verlauf des Datentransfers</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Hochladen</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>%1 deinstallieren</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>Möchten Sie die Informationen zum Konto %1 löschen?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Kontoinformationen werden gelöscht …</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
</context>
<context>
    <name>UploadLinkDialog</name>
    <message>
        <source>Upload Link</source>
        <translation>Upload-Link</translation>
    </message>
    <message>
        <source>Upload link:</source>
        <translation>Upload-Link:</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>In die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>